==> trend_etl-0.0.1-py3-none-any.whl: trend_etl/schema/args.py <==
from typing import Final

yesno = ["yes", "no"]
kafka_topics = [
    "dev-subreddits",
    "dev-submissions",
    "dev-replies",
    "dev-groups",
    "dev-posts",
    "dev-comments",
    "prod-subreddits",
    "prod-submissions",
    "prod-replies",
    "prod-groups",
    "prod-posts",
    "prod-comments",
]
catalogs = ["dev", "prod", "hive_metastore"]
catalogs_dev = 0
catalogs_prod = 1
catalogs_hive = 2
schemas = ["bronze", "silver", "gold"]
schemas_bronze = 0
schemas_silver = 1
schemas_gold = 2
# fmt: off
tables = [
    # bronze schema tables
    "subreddits_metadata_daily",    #0
    "submissions",                  #1
    "replies",                      #2
    "groups_metadata_daily",        #3
    "posts",                        #4
    "comments",                     #5
    # uuid assignments
    "group_idents",                 #6
    "subreddit_idents",             #7
    "post_idents",                  #8
    "comment_idents",               #9
    "submission_idents",            #10
    "reply_idents",                 #11
    # silver schema tables
    "facebook_posts",               #12
    "facebook_comments",            #13
    "facebook_groups",              #14
    "community_groups",             #15
    "subreddits",                   #16
    "reddit_submissions",           #17
    "reddit_replies",               #18
    "reddit_bot_users",             #19
    "docs",                         #20
    "daily_ingestion_counts",       #21
    "job_run_ingestion_counts",     #22
]
# fmt: on
# bronze schema tables
tables_subreddits_daily: Final[int] = 0
tables_submissions: Final[int] = 1
tables_replies: Final[int] = 2
tables_groups_daily: Final[int] = 3
tables_posts: Final[int] = 4
tables_comments: Final[int] = 5
# uuid assignments
tables_group_idents: Final[int] = 6
tables_subreddit_idents: Final[int] = 7
tables_post_idents: Final[int] = 8
tables_comment_idents: Final[int] = 9
tables_submission_idents: Final[int] = 10
tables_reply_idents: Final[int] = 11
# silver schema tables
tables_facebook_posts: Final[int] = 12
tables_facebook_comments: Final[int] = 13
tables_facebook_groups: Final[int] = 14
tables_community_groups: Final[int] = 15
tables_subreddits: Final[int] = 16
tables_reddit_submissions: Final[int] = 17
tables_reddit_replies: Final[int] = 18
tables_reddit_bot_users: Final[int] = 19
tables_docs: Final[int] = 20
tables_daily_ingestion_counts: Final[int] = 21
tables_job_run_ingestion_counts: Final[int] = 22
facebook_test_groups = [
    "801584718235206",
    "20002201320576",
    "3518153685070982",
    "310005509478420",
    "112520399446918",
    "798254541162450",
    "926744101932611",
    "1396191544507479",
    "1318302815779153",
    "212395830858146",
    "929259734522186",
    "1550976495296481",
]
test_subreddits = ["t5_9z94by"]
archive_paths = [
    # facebook
    "/mnt/archives/facebook/kind=groupmetadatasnapshot",
    "/mnt/archives/facebook/kind=posts",
    "/mnt/archives/facebook/kind=comments",
    # pushshift
    "/mnt/archives/reddit/kind=submissions/",
    "/mnt/archives/reddit/kind=comments",
    # reddit (api)
    "/mnt/archives/redditapi/kind=subredditmetadatasnapshot",
    "/mnt/archives/redditapi/kind=articles",
    "/mnt/archives/redditapi/kind=comments",
]
data_sources = ["facebook", "reddit"]
data_sources_facebook = 0
data_sources_reddit = 1

ner_model_path = "/dbfs/mnt/trend/projects/prodigy_ner/complete/finished_ner"
statement_types = ["group", "subreddit", "post", "comment", "submission", "reply"]
statement_type_group = 0
statement_type_subreddit = 1
statement_type_post = 2
statement_type_comment = 3
statement_type_submission = 4
statement_type_reply = 5

==> trend_etl-1.4.6-py3-none-any.whl: trend_etl/schema/args.py <==
from typing import Final

yesno = ["yes", "no"]
kafka_topics = [
    "dev-subreddits",
    "dev-submissions",
    "dev-replies",
    "dev-groups",
    "dev-posts",
    "dev-comments",
    "dev-guilds",
    "dev-channels",
    "dev-messages",
    "dev-reactions",
    "dev-members",
    "prod-subreddits",
    "prod-submissions",
    "prod-replies",
    "prod-groups",
    "prod-posts",
    "prod-comments",
    "prod-guilds",
    "prod-channels",
    "prod-messages",
    "prod-reactions",
    "prod-members",
]
catalogs = ["dev", "prod", "hive_metastore"]
catalogs_dev = 0
catalogs_prod = 1
catalogs_hive = 2
schemas = ["bronze", "silver", "gold"]
schemas_bronze = 0
schemas_silver = 1
schemas_gold = 2
# fmt: off
tables = [
    # bronze schema tables
    "subreddits_metadata_daily",    #0
    "submissions",                  #1
    "replies",                      #2
    "groups_metadata_daily",        #3
    "posts",                        #4
    "comments",                     #5
    # uuid assignments
    "group_idents",                 #6
    "subreddit_idents",             #7
    "post_idents",                  #8
    "comment_idents",               #9
    "submission_idents",            #10
    "reply_idents",                 #11
    # silver schema tables
    "facebook_posts",               #12
    "facebook_comments",            #13
    "facebook_groups",              #14
    "community_groups",             #15
    "subreddits",                   #16
    "reddit_submissions",           #17
    "reddit_replies",               #18
    "reddit_bot_users",             #19
    "docs",                         #20
    "daily_ingestion_counts",       #21
    "job_run_ingestion_counts",     #22
    # discord bronze tables
    "guilds",                       #23
    "channels",                     #24
    "messages",                     #25
    "reactions",                    #26
    # discord ident tables
    "guild_idents",                 #27
    "channel_idents",               #28
    "message_idents",               #29
    # discord silver table
    "discord_guilds",               #30
    "discord_channels",             #31
    "discord_messages",             #32
    "discord_reactions",            #33
    # NOTE: this is a view over discord_channels
    "discord_threads",              #34
    # discord members bronze table
    "members",                      #35
    # discord members silver table
    "discord_members",              #36
    "docs_noparts",                 #37
]
# fmt: on
# bronze schema tables
tables_subreddits_daily: Final[int] = 0
tables_submissions: Final[int] = 1
tables_replies: Final[int] = 2
tables_groups_daily: Final[int] = 3
tables_posts: Final[int] = 4
tables_comments: Final[int] = 5
tables_guilds: Final[int] = 23
tables_channels: Final[int] = 24
tables_messages: Final[int] = 25
tables_reactions: Final[int] = 26
tables_members: Final[int] = 35
# uuid assignments
tables_group_idents: Final[int] = 6
tables_subreddit_idents: Final[int] = 7
tables_post_idents: Final[int] = 8
tables_comment_idents: Final[int] = 9
tables_submission_idents: Final[int] = 10
tables_reply_idents: Final[int] = 11
tables_guild_idents: Final[int] = 27
tables_channel_idents: Final[int] = 28
tables_message_idents: Final[int] = 29
# silver schema tables
tables_facebook_posts: Final[int] = 12
tables_facebook_comments: Final[int] = 13
tables_facebook_groups: Final[int] = 14
tables_community_groups: Final[int] = 15
tables_subreddits: Final[int] = 16
tables_reddit_submissions: Final[int] = 17
tables_reddit_replies: Final[int] = 18
tables_reddit_bot_users: Final[int] = 19
tables_docs: Final[int] = 20
tables_docs_noparts: Final[int] = 37
tables_daily_ingestion_counts: Final[int] = 21
tables_job_run_ingestion_counts: Final[int] = 22
tables_discord_guilds: Final[int] = 30
tables_discord_channels: Final[int] = 31
tables_discord_messages: Final[int] = 32
tables_discord_reactions: Final[int] = 33
tables_discord_threads: Final[int] = 34
tables_discord_members: Final[int] = 36
facebook_test_groups = [
    "801584718235206",
    "20002201320576",
    "3518153685070982",
    "310005509478420",
    "112520399446918",
    "798254541162450",
    "926744101932611",
    "1396191544507479",
    "1318302815779153",
    "212395830858146",
    "929259734522186",
    "1550976495296481",
]
test_subreddits = ["t5_9z94by"]
archive_paths = [
    # facebook
    "/mnt/archives/facebook/kind=groupmetadatasnapshot",
    "/mnt/archives/facebook/kind=posts",
    "/mnt/archives/facebook/kind=comments",
    # pushshift
    "/mnt/archives/reddit/kind=submissions/",
    "/mnt/archives/reddit/kind=comments",
    # reddit (api)
    "/mnt/archives/redditapi/kind=subredditmetadatasnapshot",
    "/mnt/archives/redditapi/kind=articles",
    "/mnt/archives/redditapi/kind=comments",
]
data_sources = ["facebook", "reddit", "discord"]
data_sources_facebook = 0
data_sources_reddit = 1

ner_model_path = "/dbfs/mnt/trend/projects/prodigy_ner/complete/finished_ner"
statement_types = ["group", "subreddit", "post", "comment", "submission", "reply"]
statement_type_group = 0
statement_type_subreddit = 1
statement_type_post = 2
statement_type_comment = 3
statement_type_submission = 4
statement_type_reply = 5
discord_trend_employees = [
    "1116398996974477452",
    "1179456832159354930",
    "1223325766742310962",
    "741682757486510081",
    "1197548825750024232",
    "735710807962419240",
    "943888971900006450",
    "980068258084450374",
    "829877816228970556",
    "1192554388649164863",
    "1178799745133711380",
    "707234442820845568",
    "1114209896892739644",
]
# Discord threads:
# ANNOUNCEMENT_THREAD (10)
# PUBLIC_THREAD (11)
# PRIVATE_THREAD (12)
# ref: https://discord.com/developers/docs/resources/channel#channel-object-channel-types
discord_thread_types = [10, 11, 12]
